@@ -86,7 +86,7 @@
 #define KDESU_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDESU_NO_DEPRECATED
-#  define KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KDESU_NO_DEPRECATED_WARNINGS
 #  define KDESU_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDESU_DEPRECATED_WARNINGS_SINCE KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDESU_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KDESU_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -115,6 +115,12 @@
 #else
 #  define KDESU_DEPRECATED_VERSION_5_0(text)
 #endif
+
+#if KDESU_DEPRECATED_WARNINGS_SINCE >= 0x56300
+#  define KDESU_DEPRECATED_VERSION_5_99(text) KDESU_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KDESU_DEPRECATED_VERSION_5_99(text)
+#endif
 #define KDESU_DEPRECATED_VERSION_5(minor, text)      KDESU_DEPRECATED_VERSION_5_##minor(text)
 #define KDESU_DEPRECATED_VERSION(major, minor, text) KDESU_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KDESU_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDESU_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -180,7 +186,7 @@
 #define KDESU_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDESU_NO_DEPRECATED
-#  define KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KDESU_NO_DEPRECATED_WARNINGS
 #  define KDESU_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +196,7 @@
 #  ifdef KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDESU_DEPRECATED_WARNINGS_SINCE KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDESU_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KDESU_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -209,6 +215,12 @@
 #else
 #  define KDESU_DEPRECATED_VERSION_5_0(text)
 #endif
+
+#if KDESU_DEPRECATED_WARNINGS_SINCE >= 0x56300
+#  define KDESU_DEPRECATED_VERSION_5_99(text) KDESU_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KDESU_DEPRECATED_VERSION_5_99(text)
+#endif
 #define KDESU_DEPRECATED_VERSION_5(minor, text)      KDESU_DEPRECATED_VERSION_5_##minor(text)
 #define KDESU_DEPRECATED_VERSION(major, minor, text) KDESU_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KDESU_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDESU_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
